\ProvidesFile{ecmsrb2enc.def}
  [Experimental Serbian Cyrillic encoding definition file]
\DeclareFontEncoding{ECMSRB2}{}{}
\DeclareTextAccent{\`}{ECMSRB2}{0}
\DeclareTextAccent{\'}{ECMSRB2}{1}
\DeclareTextAccent{\^}{ECMSRB2}{2}
\DeclareTextAccent{\T}{ECMSRB2}{3}
\DeclareTextAccent{\D}{ECMSRB2}{4}
\DeclareTextAccent{\H}{ECMSRB2}{5}
\DeclareTextAccent{\r}{ECMSRB2}{6}
\DeclareTextCommand{\R}{ECMSRB2}[1]
   {\hmode@bgroup\o@lign{\relax#1\crcr\hidewidth\ltx@sh@ft{-3ex}%
     \vbox to.2ex{\hbox{\char6}\vss}\hidewidth}\egroup}
\DeclareTextAccent{\v}{ECMSRB2}{7}
\DeclareTextAccent{\u}{ECMSRB2}{8}
\DeclareTextAccent{\U}{ECMSRB2}{8}
\DeclareTextAccent{\=}{ECMSRB2}{9}
\DeclareTextCommand{\b}{ECMSRB2}[1]
   {\hmode@bgroup\o@lign{\relax#1\crcr\hidewidth\ltx@sh@ft{-3ex}%
     \vbox to.2ex{\hbox{\char9}\vss}\hidewidth}\egroup}
\DeclareTextAccent{\.}{ECMSRB2}{10}
\DeclareTextCommand{\d}{ECMSRB2}[1]
   {\hmode@bgroup
    \o@lign{\relax#1\crcr\hidewidth\ltx@sh@ft{-1ex}.\hidewidth}\egroup}
\DeclareTextCommand{\c}{ECMSRB2}[1]
   {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent11 #1%
     \else{\ooalign{\unhbox\z@\crcr
        \hidewidth\char11\hidewidth}}\fi}
\DeclareTextCommand{\k}{ECMSRB2}[1]
   {\hmode@bgroup\ooalign{\null#1\crcr\hidewidth\char12}\egroup}
\DeclareTextSymbol{\textcurrency}{ECMSRB2}{13}
\DeclareTextSymbol{\guilsinglleft}{ECMSRB2}{14}
\DeclareTextSymbol{\guilsinglright}{ECMSRB2}{15}
\DeclareTextSymbol{\textquotedblleft}{ECMSRB2}{16}
\DeclareTextSymbol{\textquotedblright}{ECMSRB2}{17}
\DeclareTextSymbol{\quotedblbase}{ECMSRB2}{18}
\DeclareTextSymbol{\guillemotleft}{ECMSRB2}{19}
\DeclareTextSymbol{\guillemotright}{ECMSRB2}{20}
\DeclareTextSymbol{\textendash}{ECMSRB2}{21}
\DeclareTextSymbol{\cyrdash}{ECMSRB2}{22}
\DeclareTextSymbol{\textemdash}{ECMSRB2}{22}
\DeclareTextSymbol{\texteuro}{ECMSRB2}{23}
\DeclareTextCommand{\textperthousand}{ECMSRB2}
   {\%\char 24 }
\DeclareTextCommand{\textpertenthousand}{ECMSRB2}
   {\%\char 24\char 24 }
\DeclareTextSymbol{\i}{ECMSRB2}{25}
\DeclareTextSymbol{\j}{ECMSRB2}{26}
\DeclareTextAccent{\"}{ECMSRB2}{27}
\DeclareTextAccent{\C}{ECMSRB2}{27}
\DeclareTextAccent{\~}{ECMSRB2}{28}
\DeclareTextAccent{\f}{ECMSRB2}{28}
\DeclareTextSymbol{\textsection}{ECMSRB2}{29}
\DeclareTextSymbol{\textvisiblespace}{ECMSRB2}{32}
\DeclareTextSymbol{\textquotedbl}{ECMSRB2}{34}
\DeclareTextSymbol{\textdollar}{ECMSRB2}{36}
\DeclareTextSymbol{\textquoteright}{ECMSRB2}{39}
\DeclareTextSymbol{\textless}{ECMSRB2}{60}
\DeclareTextSymbol{\textgreater}{ECMSRB2}{62}
\DeclareTextSymbol{\CYRA}{ECMSRB2}{65}
\DeclareTextSymbol{\CYRB}{ECMSRB2}{66}
\DeclareTextSymbol{\CYRC}{ECMSRB2}{67}
\DeclareTextSymbol{\CYRD}{ECMSRB2}{68}
\DeclareTextSymbol{\CYRE}{ECMSRB2}{69}
\DeclareTextSymbol{\CYRF}{ECMSRB2}{70}
\DeclareTextSymbol{\CYRG}{ECMSRB2}{71}
\DeclareTextSymbol{\CYRH}{ECMSRB2}{72}
\DeclareTextSymbol{\CYRI}{ECMSRB2}{73}
\DeclareTextSymbol{\CYRJE}{ECMSRB2}{74}
\DeclareTextSymbol{\CYRK}{ECMSRB2}{75}
\DeclareTextSymbol{\CYRL}{ECMSRB2}{76}
\DeclareTextSymbol{\CYRM}{ECMSRB2}{77}
\DeclareTextSymbol{\CYRN}{ECMSRB2}{78}
\DeclareTextSymbol{\CYRO}{ECMSRB2}{79}
\DeclareTextSymbol{\CYRP}{ECMSRB2}{80}
\DeclareTextSymbol{\CYRYU}{ECMSRB2}{81}
\DeclareTextSymbol{\CYRR}{ECMSRB2}{82}
\DeclareTextSymbol{\CYRS}{ECMSRB2}{83}
\DeclareTextSymbol{\CYRT}{ECMSRB2}{84}
\DeclareTextSymbol{\CYRU}{ECMSRB2}{85}
\DeclareTextSymbol{\CYRV}{ECMSRB2}{86}
\DeclareTextSymbol{\CYRYA}{ECMSRB2}{87}
\DeclareTextSymbol{\CYRHRDSN}{ECMSRB2}{88}
\DeclareTextSymbol{\CYRSFTSN}{ECMSRB2}{89}
\DeclareTextSymbol{\CYRZ}{ECMSRB2}{90}
\DeclareTextSymbol{\CYRCH}{ECMSRB2}{128}
\DeclareTextSymbol{\CYRTSHE}{ECMSRB2}{129}
\DeclareTextSymbol{\CYRDJE}{ECMSRB2}{130}
\DeclareTextSymbol{\CYRSH}{ECMSRB2}{131}
\DeclareTextSymbol{\CYRZH}{ECMSRB2}{132}
\DeclareTextSymbol{\CYRSJE}{ECMSRB2}{133}
\DeclareTextSymbol{\CYRZJE}{ECMSRB2}{134}
\DeclareTextSymbol{\CYRDZE}{ECMSRB2}{135}
\DeclareTextSymbol{\CYRGJE}{ECMSRB2}{136}
\DeclareTextSymbol{\CYRKJE}{ECMSRB2}{137}
\DeclareTextSymbol{\CYRYAT}{ECMSRB2}{138}
\DeclareTextSymbol{\CYRLJE}{ECMSRB2}{141}
\DeclareTextSymbol{\CYRNJE}{ECMSRB2}{142}
\DeclareTextSymbol{\CYRDZHE}{ECMSRB2}{143}
\DeclareTextSymbol{\cyra}{ECMSRB2}{97}
\DeclareTextSymbol{\cyrb}{ECMSRB2}{98}
\DeclareTextSymbol{\cyrc}{ECMSRB2}{99}
\DeclareTextSymbol{\cyrd}{ECMSRB2}{100}
\DeclareTextSymbol{\cyre}{ECMSRB2}{101}
\DeclareTextSymbol{\cyrf}{ECMSRB2}{102}
\DeclareTextSymbol{\cyrg}{ECMSRB2}{103}
\DeclareTextSymbol{\cyrh}{ECMSRB2}{104}
\DeclareTextSymbol{\cyri}{ECMSRB2}{105}
\DeclareTextSymbol{\cyrje}{ECMSRB2}{106}
\DeclareTextSymbol{\cyrk}{ECMSRB2}{107}
\DeclareTextSymbol{\cyrl}{ECMSRB2}{108}
\DeclareTextSymbol{\cyrm}{ECMSRB2}{109}
\DeclareTextSymbol{\cyrn}{ECMSRB2}{110}
\DeclareTextSymbol{\cyro}{ECMSRB2}{111}
\DeclareTextSymbol{\cyrp}{ECMSRB2}{112}
\DeclareTextSymbol{\cyryu}{ECMSRB2}{113}
\DeclareTextSymbol{\cyrr}{ECMSRB2}{114}
\DeclareTextSymbol{\cyrs}{ECMSRB2}{115}
\DeclareTextSymbol{\cyrt}{ECMSRB2}{116}
\DeclareTextSymbol{\cyru}{ECMSRB2}{117}
\DeclareTextSymbol{\cyrv}{ECMSRB2}{118}
\DeclareTextSymbol{\cyrya}{ECMSRB2}{119}
\DeclareTextSymbol{\cyrhrdsn}{ECMSRB2}{120}
\DeclareTextSymbol{\cyrsftsn}{ECMSRB2}{121}
\DeclareTextSymbol{\cyrz}{ECMSRB2}{122}
\DeclareTextSymbol{\cyrch}{ECMSRB2}{144}
\DeclareTextSymbol{\cyrtshe}{ECMSRB2}{145}
\DeclareTextSymbol{\cyrdje}{ECMSRB2}{146}
\DeclareTextSymbol{\cyrsh}{ECMSRB2}{147}
\DeclareTextSymbol{\cyrzh}{ECMSRB2}{148}
\DeclareTextSymbol{\cyrsje}{ECMSRB2}{149}
\DeclareTextSymbol{\cyrzje}{ECMSRB2}{150}
\DeclareTextSymbol{\cyrdze}{ECMSRB2}{151}
\DeclareTextSymbol{\cyrgje}{ECMSRB2}{152}
\DeclareTextSymbol{\cyrkje}{ECMSRB2}{153}
\DeclareTextSymbol{\cyryat}{ECMSRB2}{154}
\DeclareTextSymbol{\cyrlje}{ECMSRB2}{157}
\DeclareTextSymbol{\cyrnje}{ECMSRB2}{158}
\DeclareTextSymbol{\cyrdzhe}{ECMSRB2}{159}
\DeclareTextSymbol{\textbackslash}{ECMSRB2}{92}
\DeclareTextSymbol{\textasciicircum}{ECMSRB2}{94}
\DeclareTextSymbol{\textunderscore}{ECMSRB2}{95}
\DeclareTextSymbol{\textquoteleft}{ECMSRB2}{96}
\DeclareTextSymbol{\textbraceleft}{ECMSRB2}{123}
\DeclareTextSymbol{\textbar}{ECMSRB2}{124}
\DeclareTextSymbol{\textbraceright}{ECMSRB2}{125}
\DeclareTextSymbol{\textasciitilde}{ECMSRB2}{126}
\DeclareTextComposite{\v}{ECMSRB2}{C}{128}
\DeclareTextComposite{\'}{ECMSRB2}{C}{129}
\DeclareTextSymbol{\DJ}{ECMSRB2}{130}
\DeclareTextComposite{\v}{ECMSRB2}{S}{131}
\DeclareTextComposite{\v}{ECMSRB2}{Z}{132}
\DeclareTextComposite{\'}{ECMSRB2}{S}{133}
\DeclareTextComposite{\'}{ECMSRB2}{Z}{134}
\DeclareTextSymbol{\EZH}{ECMSRB2}{135}
\DeclareTextComposite{\v}{ECMSRB2}{E}{138}
\DeclareTextComposite{\v}{ECMSRB2}{c}{144}
\DeclareTextComposite{\'}{ECMSRB2}{c}{145}
\DeclareTextSymbol{\dj}{ECMSRB2}{146}
\DeclareTextComposite{\v}{ECMSRB2}{s}{147}
\DeclareTextComposite{\v}{ECMSRB2}{z}{148}
\DeclareTextComposite{\'}{ECMSRB2}{s}{149}
\DeclareTextComposite{\'}{ECMSRB2}{z}{150}
\DeclareTextSymbol{\ezh}{ECMSRB2}{151}
\DeclareTextComposite{\v}{ECMSRB2}{e}{154}
\DeclareTextSymbol{\textnumero}{ECMSRB2}{170}
\DeclareTextSymbol{\texttimes}{ECMSRB2}{171}
\DeclareTextSymbol{\textdiv}{ECMSRB2}{172}
\DeclareTextComposite{\v}{ECMSRB2}{\CYRC}{128}
\DeclareTextComposite{\'}{ECMSRB2}{\CYRC}{129}
\DeclareTextComposite{\v}{ECMSRB2}{\CYRS}{131}
\DeclareTextComposite{\v}{ECMSRB2}{\CYRZ}{132}
\DeclareTextComposite{\'}{ECMSRB2}{\CYRS}{133}
\DeclareTextComposite{\'}{ECMSRB2}{\CYRZ}{134}
\DeclareTextComposite{\v}{ECMSRB2}{\CYRE}{138}
\DeclareTextComposite{\v}{ECMSRB2}{\cyrc}{144}
\DeclareTextComposite{\'}{ECMSRB2}{\cyrc}{145}
\DeclareTextComposite{\v}{ECMSRB2}{\cyrs}{147}
\DeclareTextComposite{\v}{ECMSRB2}{\cyrz}{148}
\DeclareTextComposite{\'}{ECMSRB2}{\cyrs}{149}
\DeclareTextComposite{\'}{ECMSRB2}{\cyrz}{150}
\DeclareTextComposite{\v}{ECMSRB2}{\cyre}{154}
\endinput
