\ProvidesFile{ecmsrb1enc.def}
  [Experimental Serbian Latin encoding definition file]
\DeclareFontEncoding{ECMSRB1}{}{}
\DeclareTextAccent{\`}{ECMSRB1}{0}
\DeclareTextAccent{\'}{ECMSRB1}{1}
\DeclareTextAccent{\^}{ECMSRB1}{2}
\DeclareTextAccent{\T}{ECMSRB1}{3}
\DeclareTextAccent{\D}{ECMSRB1}{4}
\DeclareTextAccent{\H}{ECMSRB1}{5}
\DeclareTextAccent{\r}{ECMSRB1}{6}
\DeclareTextCommand{\R}{ECMSRB1}[1]
   {\hmode@bgroup\o@lign{\relax#1\crcr\hidewidth\ltx@sh@ft{-3ex}%
     \vbox to.2ex{\hbox{\char6}\vss}\hidewidth}\egroup}
\DeclareTextAccent{\v}{ECMSRB1}{7}
\DeclareTextAccent{\u}{ECMSRB1}{8}
\DeclareTextAccent{\U}{ECMSRB1}{8}
\DeclareTextAccent{\=}{ECMSRB1}{9}
\DeclareTextCommand{\b}{ECMSRB1}[1]
   {\hmode@bgroup\o@lign{\relax#1\crcr\hidewidth\ltx@sh@ft{-3ex}%
     \vbox to.2ex{\hbox{\char9}\vss}\hidewidth}\egroup}
\DeclareTextAccent{\.}{ECMSRB1}{10}
\DeclareTextCommand{\d}{ECMSRB1}[1]
   {\hmode@bgroup
    \o@lign{\relax#1\crcr\hidewidth\ltx@sh@ft{-1ex}.\hidewidth}\egroup}
\DeclareTextCommand{\c}{ECMSRB1}[1]
   {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent11 #1%
     \else{\ooalign{\unhbox\z@\crcr
        \hidewidth\char11\hidewidth}}\fi}
\DeclareTextCommand{\k}{ECMSRB1}[1]
   {\hmode@bgroup\ooalign{\null#1\crcr\hidewidth\char12}\egroup}
\DeclareTextSymbol{\textcurrency}{ECMSRB1}{13}
\DeclareTextSymbol{\guilsinglleft}{ECMSRB1}{14}
\DeclareTextSymbol{\guilsinglright}{ECMSRB1}{15}
\DeclareTextSymbol{\textquotedblleft}{ECMSRB1}{16}
\DeclareTextSymbol{\textquotedblright}{ECMSRB1}{17}
\DeclareTextSymbol{\quotedblbase}{ECMSRB1}{18}
\DeclareTextSymbol{\guillemotleft}{ECMSRB1}{19}
\DeclareTextSymbol{\guillemotright}{ECMSRB1}{20}
\DeclareTextSymbol{\textendash}{ECMSRB1}{21}
\DeclareTextSymbol{\cyrdash}{ECMSRB1}{22}
\DeclareTextSymbol{\textemdash}{ECMSRB1}{22}
\DeclareTextSymbol{\texteuro}{ECMSRB1}{23}
\DeclareTextCommand{\textperthousand}{ECMSRB1}
   {\%\char 24 }
\DeclareTextCommand{\textpertenthousand}{ECMSRB1}
   {\%\char 24\char 24 }
\DeclareTextSymbol{\i}{ECMSRB1}{25}
\DeclareTextSymbol{\j}{ECMSRB1}{26}
\DeclareTextAccent{\"}{ECMSRB1}{27}
\DeclareTextAccent{\C}{ECMSRB1}{27}
\DeclareTextAccent{\~}{ECMSRB1}{28}
\DeclareTextAccent{\f}{ECMSRB1}{28}
\DeclareTextSymbol{\textsection}{ECMSRB1}{29}
\DeclareTextSymbol{\textvisiblespace}{ECMSRB1}{32}
\DeclareTextSymbol{\textquotedbl}{ECMSRB1}{34}
\DeclareTextSymbol{\textdollar}{ECMSRB1}{36}
\DeclareTextSymbol{\textquoteright}{ECMSRB1}{39}
\DeclareTextSymbol{\textless}{ECMSRB1}{60}
\DeclareTextSymbol{\textgreater}{ECMSRB1}{62}
\DeclareTextSymbol{\textbackslash}{ECMSRB1}{92}
\DeclareTextSymbol{\textasciicircum}{ECMSRB1}{94}
\DeclareTextSymbol{\textunderscore}{ECMSRB1}{95}
\DeclareTextSymbol{\textquoteleft}{ECMSRB1}{96}
\DeclareTextSymbol{\textbraceleft}{ECMSRB1}{123}
\DeclareTextSymbol{\textbar}{ECMSRB1}{124}
\DeclareTextSymbol{\textbraceright}{ECMSRB1}{125}
\DeclareTextSymbol{\textasciitilde}{ECMSRB1}{126}
\DeclareTextComposite{\.}{ECMSRB1}{i}{`\i}
\DeclareTextComposite{\v}{ECMSRB1}{C}{128}
\DeclareTextComposite{\'}{ECMSRB1}{C}{129}
\DeclareTextSymbol{\DJ}{ECMSRB1}{130}
\DeclareTextComposite{\v}{ECMSRB1}{S}{131}
\DeclareTextComposite{\v}{ECMSRB1}{Z}{132}
\DeclareTextComposite{\'}{ECMSRB1}{S}{133}
\DeclareTextComposite{\'}{ECMSRB1}{Z}{134}
\DeclareTextSymbol{\EZH}{ECMSRB1}{135}
\DeclareTextComposite{\v}{ECMSRB1}{E}{138}
\DeclareTextComposite{\v}{ECMSRB1}{c}{144}
\DeclareTextComposite{\'}{ECMSRB1}{c}{145}
\DeclareTextSymbol{\dj}{ECMSRB1}{146}
\DeclareTextComposite{\v}{ECMSRB1}{s}{147}
\DeclareTextComposite{\v}{ECMSRB1}{z}{148}
\DeclareTextComposite{\'}{ECMSRB1}{s}{149}
\DeclareTextComposite{\'}{ECMSRB1}{z}{150}
\DeclareTextSymbol{\ezh}{ECMSRB1}{151}
\DeclareTextComposite{\v}{ECMSRB1}{e}{154}
\DeclareTextSymbol{\textnumero}{ECMSRB1}{170}
\DeclareTextSymbol{\texttimes}{ECMSRB1}{171}
\DeclareTextSymbol{\textdiv}{ECMSRB1}{172}
\endinput
